loadres — ModelicaRes v0.7.1 Documentation
Description: Python module to set up, plot, and analyze Modelica simulations
Keywords: Modelica, Python, plot, results, simulation, experiment

### Navigation

- index
- modules |
- next |
- previous |
- ModelicaRes v0.7.1 Documentation »

# `loadres`

Load results from Modelica simulation(s) and provide a Python interpreter to analyze the results.

This script can be executed at the command line. It will accept as arguments the names of result files or names of directories with result files. The filenames may contain wildcards. If no arguments are given, the script provides a dialog to choose a file or folder. Finally, it provides working session of IPython with the results preloaded. PyLab is directly imported (`from pylab import *`) to provide many functions of NumPy and matplotlib (e.g., `sin()` and `plot()`).

Example:

    $ loadres examples
    Valid: SimRes('.../examples/ChuaCircuit.mat')
    Valid: SimRes('.../examples/ChuaCircuit2.mat')
    Valid: SimRes('.../examples/ThreeTanks.mat')
    Valid: LinRes('.../examples/PID.mat')
    Simulation results have been loaded into sims[0] through sims[2].
    A linearization result has been loaded into lin.

    In [1]:

where ‘...’ depends on the local system.

### Navigation

- index
- modules |
- next |
- previous |
- ModelicaRes v0.7.1 Documentation »